@@ -1,8 +1,7 @@
-#!/usr/bin/perl
+package Cache::Cascade; # git description: Cache-Cascade-0.05-7-g0b8be6d
+# ABSTRACT: Get/set values to/from a group of caches, with some advanced semantics.
 
-package Cache::Cascade;
 use Any::Moose;
-
 use Carp qw/croak/;
 
 sub _eval {
@@ -13,7 +12,7 @@ sub _eval {
 
 use namespace::clean -except => [qw(meta)];
 
-our $VERSION = "0.05";
+our $VERSION = '0.06';
 
 has caches => (
 	isa => "ArrayRef",
@@ -126,10 +125,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Cache::Cascade - Get/set values to/from a group of caches, with some advanced
-semantics.
+Cache::Cascade - Get/set values to/from a group of caches, with some advanced semantics.
+
+=head1 VERSION
+
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -147,6 +151,8 @@ semantics.
 
 =head1 DESCRIPTION
 
+=for stopwords tradeoff multiserver MemoryCache FastMmap
+
 In a multiprocess, and especially a multiserver application caching is a very
 effective means of improving results.
 
@@ -160,15 +166,15 @@ This module attempts to make a transparent cascade of caches using several
 backends.
 
 The idea is to search from the cheapest backend to the most expensive, and
-depending on the options also cache results in the chepear backends.
+depending on the options also cache results in the cheaper backends.
 
 The benefits of using a cascade are that if the chance of a hit is much higher
-in a slow cache, but checking a cheap cache is negligiable in comparison, we
+in a slow cache, but checking a cheap cache is negligible in comparison, we
 may already have the result we want in the cheap cache. Configure your
 expiration policy so that there is approximately an order of magnitude better
 probability of cache hits (bigger cache) for each level of the cascade.
 
-=item FIELDS
+=head1 FIELDS
 
 =over 4
 
@@ -233,8 +239,6 @@ These two methods return the first callback they found.
 
 These two methods set the callback for all the caches.
 
-=item 
-
 =item get_and_float_result $key, @caches
 
 This is used to implement the C<float_hits> behavior of C<get> recursively.
@@ -243,7 +247,7 @@ This is used to implement the C<float_hits> behavior of C<get> recursively.
 
 =head1 CAVEATS
 
-When you set or remove a key from the cascade and this propagates downards, for
+When you set or remove a key from the cascade and this propagates downwards, for
 example from MemoryCache to FastMmap, other cascades will not notice the change
 until their own MemoryCache is expired.
 
@@ -255,12 +259,26 @@ changing data then you should use a cascade.
 
 L<Cache>
 
-=head1 VERSION CONTROL
+=head1 SUPPORT
 
-This module is maintained using Darcs. You can get the latest version from
-L<http://nothingmuch.woobling.org/Cache-Cascade/>, and use C<darcs send> to
-commit changes.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Cache-Cascade>
+(or L<bug-Cache-Cascade@rt.cpan.org|mailto:bug-Cache-Cascade@rt.cpan.org>).
+
+=head1 AUTHOR
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=head1 CONTRIBUTOR
+
+=for stopwords Karen Etheridge
+
+Karen Etheridge <ether@cpan.org>
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2006 by יובל קוג'מן (Yuval Kogman).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
